.result, .retired, .fastest, .wildcard {
  color: #FFFFFF;
  font-variant: small-caps;
  border-radius: 15%; }

.retired {
  background-color: red; }

.fastest {
  background-color: blue; }

.wildcard {
  background-color: orange; }

.finish_1 {
  background-color: gold !important;
  font-size: 1.8em; }

.finish_2 {
  background-color: silver !important;
  font-size: 1.6em; }

.finish_3 {
  background-color: #CD7F32 !important;
  font-size: 1.3em; }

.points {
  background-color: darkseagreen; }

tr:not(.points) {
  font-size: 0.9em; }

.result_error {
  background-color: #E34A3E; }

.champion_points, .champion_tag {
  font-size: 1.3em;
  font-weight: bolder; }

select[name='scoring'] {
  display: inline-table;
  max-width: 300px; }

/*# sourceMappingURL=style.css.map */
