{% load i18n %}
    <table class="table table-condensed table-striped table-hover">
    <tr>
        <th class="col-md-4">{%  trans 'Points' %}</th>
        <th class="col-md-8">{%  trans 'Team' %}</th>
    </tr>
    {% for points,team in rank %}
        <tr>
        <td>{{ points }}</td>
        <td>{{ team }}</td>
        </tr>
    {% endfor %}

    </table>