{% load champion_filter i18n %}
<table class="table table-condensed table-striped table-hover">
    <thead>
        <tr>
        <th>{%  trans 'Driver' %}</th>
        <th>{%  trans 'Team' %}</th>
        {% for position in positions %}
            <th>{{ position }}</th>
        {% endfor %}
    </tr>
    </thead>

    {% for positions_str,driver,team, positions_list in rank %}
        <tr>
        <td>{{ driver }}</td>
        <td>{{ team }}</td>
        {% for position in positions_list %}
            <td>{{ position }}</td>
        {% endfor %}
        </tr>
    {% endfor %}

    </table>