{% extends 'driver27/base.html' %}
{% load i18n %}
{% block dr27_menu %}
    {% include 'driver27/season/season-menu-pre.html' %}
    {% include 'driver27/season/season-menu.html' %}
{% endblock %}
{% block dr27_content %}
    {{ block.super }}

    {% with rank=driver_rank %}
        {% include 'driver27/driver/driver-list-table.html' %}
    {% endwith %}

    {% with rank=team_rank %}
        {% include 'driver27/team/team-list-table.html' %}
    {% endwith %}
{% endblock %}