{% load i18n %}
<li class="nav-item">
    <a class="nav-link" href="{% url 'season-team' season.competition.slug season.year %}">{%  trans 'Teams' %}</a>
</li>
<li class="nav-item">
    <a>>></a>
</li>
<li class="nav-item">
    <a class="nav-link" href="{% url 'season-team-record-index' season.competition.slug season.year %}">{%  trans 'Records' %}</a>
</li>