{% for record_label, record_code in record_codes %}
<option value="{% url record_url season.competition.slug season.year record_code %}"
{% if record_code == record and rank_type == rank_group %}selected{% endif %}>{{ record_label }}</option>
{% endfor %}