{% extends 'bootstrap3/bootstrap3.html' %}
{% load bootstrap3 static i18n %}

{% block bootstrap3_title %}{{ title }} :: DR27{% endblock %}

{% block bootstrap3_content %}
    <div class="container">
    <h1>{% block title %}Driver27{% endblock %}</h1>
      <div class="header clearfix">
        <nav>
          <ul class="nav nav-pills pull-xs-right">
            <li class="nav-item">
              <a class="nav-link active" href="/">{% trans 'Home' %} <span class="sr-only">(current)</span></a>
            </li>

              {% block dr27_menu %}
              {% endblock %}
          </ul>
        </nav>
          <h4>{{ title }}</h4>
      </div>
              {% block dr27_content %}
              {% endblock %}
      </div>

{% endblock %}

{% block bootstrap3_extra_head %}

    <link rel="stylesheet" href="{% static 'driver27/css/style.css' %}">

{% endblock %}